// import { ChevronUpIcon } from '@chakra-ui/icons'
import { Avatar, Box, Button, Fade, Flex, Image, Text } from '@chakra-ui/react'
import moment from 'moment'
import Link from 'next/link'
import React from 'react'

const CardDetail = ({ data }: { data: any }) => {
    return (
      <>
        <Box border="1px" p={3} rounded="20px" mt="120px">
          <Flex gap={2} alignItems="center" w="100%">
            <Flex flexDirection="row" alignItems="center" w="100%" gap={2} cursor="pointer">
              <Avatar name={data?.created_by?.first_name} size="sm" />
              <Text fontSize="lg" fontWeight="bold" textTransform="uppercase">
                {data?.created_by?.first_name} {data?.created_by?.last_name ?? ""} | {data?.contact_person}
              </Text>
              <Box ms="auto">{/* <ChevronUpIcon width="20px" height="20px" /> */}</Box>
            </Flex>
          </Flex>
          <Fade in>
            <Box py="1" mt={3} px={0} rounded="md">
              <Flex rowGap={1} alignItems="center" flexWrap="wrap" justifyContent="space-between">
                <Box width="50%">
                  <Text fontSize="sm" fontWeight="bold">
                    Contact Person: &nbsp;
                    <Text as="span" fontWeight="normal">
                      {data?.contact_person}
                    </Text>
                  </Text>
                </Box>
                <Box width="50%">
                  <Text fontSize="sm" fontWeight="bold">
                    Mobile No: &nbsp;
                    <Text as="span" fontWeight="normal">
                      {data?.mobile_no}
                    </Text>
                  </Text>
                </Box>
                <Box width="50%">
                  <Text fontSize="sm" fontWeight="bold">
                    Paid Amount: &nbsp;
                    <Text as="span" fontWeight="normal">
                      {data?.paid_amount}
                    </Text>
                  </Text>
                </Box>
                <Box width="50%">
                  <Text fontSize="sm" fontWeight="bold">
                    DC Request: &nbsp;
                    <Text as="span" fontWeight="normal">
                      {data?.dc_request == 1 ? "Yes" : "No"}
                    </Text>
                  </Text>
                </Box>
                <Box width="50%">
                  <Text fontSize="sm" fontWeight="bold">
                    Meter/ UnMeter: &nbsp;
                    <Text as="span" fontWeight="normal">
                      {data?.meter_un_meter == 1 ? "Yes" : "No"}
                    </Text>
                  </Text>
                </Box>
                {data?.meter_un_meter == 1 && (
                  <>
                    <Box width="50%">
                      <Text fontSize="sm" fontWeight="bold">
                        Meter Reading: &nbsp;
                        <Text as="span" fontWeight="normal">
                          {data?.meter_reading}
                        </Text>
                      </Text>
                    </Box>
                    <Box width="50%">
                      <Text fontSize="sm" fontWeight="bold">
                        Meter No: &nbsp;
                        <Text as="span" fontWeight="normal">
                          {data?.meter_no}
                        </Text>
                      </Text>
                    </Box>
                  </>
                )}
                {data?.meter_un_meter == 0 && (
                  <Box width="50%">
                    <Text fontSize="sm" fontWeight="bold">
                      Reason for Un meter: &nbsp;
                      <Text as="span" fontWeight="normal">
                        {data?.un_meter_reason}
                      </Text>
                    </Text>
                  </Box>
                )}
                <Box width="50%">
                  <Text fontSize="sm" fontWeight="bold">
                    Remarks: &nbsp;
                    <Text as="span" fontWeight="normal">
                      {data?.remarks}
                    </Text>
                  </Text>
                </Box>
                <Box width="50%">
                  <Text fontSize="sm" fontWeight="bold">
                    Additional Remarks: &nbsp;
                    <Text as="span" fontWeight="normal">
                      {data?.additional_remarks}
                    </Text>
                  </Text>
                </Box>
                <Box width="50%">
                  <Text fontSize="sm" fontWeight="bold">
                    Created At: &nbsp;
                    <Text as="span" fontWeight="normal">
                      {moment(data?.created_at).fromNow()}
                    </Text>
                  </Text>
                </Box>
                <Box width="100%">
                  <Text fontSize="sm" fontWeight="bold">
                    Attachments: &nbsp;
                    {data?.attachments?.map((attachment: any, index: number) => (
                      <Link key={index} href={attachment?.file?.link || "#"} target="_blank">
                        <Image key={index} src={attachment?.file?.link} alt="attachment" boxSize="200px" mt="10px" objectFit="contain" />
                      </Link>
                    ))}
                  </Text>
                </Box>
              </Flex>
            </Box>
          </Fade>

          {data?.offline && (
            <Flex columnGap={1} alignItems="center" mt="6">
              <Button size="sm" px="3">
                Upload
              </Button>
            </Flex>
          )}
        </Box>
      </>
    );
}

export default CardDetail;